from distutils.core import setup

setup(
       name        =  'lyf111111',
       version     =  '1.2.0',
       py_modules  =  ['lyf111111'],
       author      =  'liuyufei',
       author_email=  '2868393672@qq.com',
       url         =  'http://www.headfirstlabs.com',
       description =  'A simple printer of nested lists',
     )
